@@ -9,8 +9,12 @@ use serde::de::DeserializeOwned;
 pub mod types;
 
 use types::BasicAuth;
+use types::BlocklistUpdate;
 use types::SessionGet;
 use types::SessionStats;
+use types::SessionClose;
+use types::PortTest;
+use types::FreeSpace;
 use types::TorrentAction;
 use types::{Id, Torrent, TorrentGetField, Torrents};
 use types::{Nothing, Result, RpcRequest, RpcResponse, RpcResponseArgument, TorrentRenamePath};
@@ -104,7 +108,7 @@ impl TransClient {
     ///         Ok(_) => println!("Yay!"),
     ///         Err(_) => panic!("Oh no!")
     ///     }
-    ///     println!("Rpc reqsponse is ok: {}", response?.is_ok());
+    ///     println!("Rpc response is ok: {}", response?.is_ok());
     ///     Ok(())
     /// }
     /// ```
@@ -140,7 +144,7 @@ impl TransClient {
     ///         Ok(_) => println!("Yay!"),
     ///         Err(_) => panic!("Oh no!")
     ///     }
-    ///     println!("Rpc reqsponse is ok: {}", response?.is_ok());
+    ///     println!("Rpc response is ok: {}", response?.is_ok());
     ///     Ok(())
     /// }
     /// ```
@@ -148,6 +152,151 @@ impl TransClient {
         self.call(RpcRequest::session_stats()).await
     }
 
+    /// Performs a session close call
+    ///
+    /// # Errors
+    ///
+    /// Any IO Error or Deserialization error
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// extern crate transmission_rpc;
+    ///
+    /// use std::env;
+    /// use dotenv::dotenv;
+    /// use transmission_rpc::TransClient;
+    /// use transmission_rpc::types::{Result, RpcResponse, BasicAuth, SessionClose};
+    ///
+    /// #[tokio::main]
+    /// async fn main() -> Result<()> {
+    ///     dotenv().ok();
+    ///     env_logger::init();
+    ///     let url= env::var("TURL")?;
+    ///     let basic_auth = BasicAuth{user: env::var("TUSER")?, password: env::var("TPWD")?};
+    ///     let client = TransClient::with_auth(&url, basic_auth);
+    ///     let response: Result<RpcResponse<SessionClose>> = client.session_close().await;
+    ///     match response {
+    ///         Ok(_) => println!("Yay!"),
+    ///         Err(_) => panic!("Oh no!")
+    ///     }
+    ///     println!("Rpc response is ok: {}", response?.is_ok());
+    ///     Ok(())
+    /// }
+    /// ```
+    pub async fn session_close(&self) -> Result<RpcResponse<SessionClose>> {
+        self.call(RpcRequest::session_close()).await
+    }
+
+    /// Performs a blocklist update call
+    ///
+    /// # Errors
+    ///
+    /// Any IO Error or Deserialization error
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// extern crate transmission_rpc;
+    ///
+    /// use std::env;
+    /// use dotenv::dotenv;
+    /// use transmission_rpc::TransClient;
+    /// use transmission_rpc::types::{Result, BlocklistUpdate, RpcResponse, BasicAuth};
+    ///
+    /// #[tokio::main]
+    /// async fn main() -> Result<()> {
+    ///     dotenv().ok();
+    ///     env_logger::init();
+    ///     let url= env::var("TURL")?;
+    ///     let basic_auth = BasicAuth{user: env::var("TUSER")?, password: env::var("TPWD")?};
+    ///     let client = TransClient::with_auth(&url, basic_auth);
+    ///     let response: Result<RpcResponse<BlocklistUpdate>> = client.blocklist_update().await;
+    ///     match response {
+    ///         Ok(_) => println!("Yay!"),
+    ///         Err(_) => panic!("Oh no!")
+    ///     }
+    ///     println!("Rpc response is ok: {}", response?.is_ok());
+    ///     Ok(())
+    /// }
+    /// ```
+    pub async fn blocklist_update(&self) -> Result<RpcResponse<BlocklistUpdate>> {
+        self.call(RpcRequest::blocklist_update()).await
+    }
+
+    /// Performs a session stats call
+    ///
+    /// # Errors
+    ///
+    /// Any IO Error or Deserialization error
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// extern crate transmission_rpc;
+    ///
+    /// use std::env;
+    /// use dotenv::dotenv;
+    /// use transmission_rpc::TransClient;
+    /// use transmission_rpc::types::{Result, RpcResponse, BasicAuth, FreeSpace};
+    ///
+    /// #[tokio::main]
+    /// async fn main() -> Result<()> {
+    ///     dotenv().ok();
+    ///     env_logger::init();
+    ///     let url= env::var("TURL")?;
+    ///     let dir = env::var("TDIR")?;
+    ///     let basic_auth = BasicAuth{user: env::var("TUSER")?, password: env::var("TPWD")?};
+    ///     let client = TransClient::with_auth(&url, basic_auth);
+    ///     let response: Result<RpcResponse<FreeSpace>> = client.free_space(dir).await;
+    ///     match response {
+    ///         Ok(_) => println!("Yay!"),
+    ///         Err(_) => panic!("Oh no!")
+    ///     }
+    ///     println!("Rpc response is ok: {}", response?.is_ok());
+    ///     Ok(())
+    /// }
+    /// ```
+    pub async fn free_space(&self, path: String) -> Result<RpcResponse<FreeSpace>> {
+        self.call(RpcRequest::free_space(path)).await
+    }
+
+    /// Performs a port test call
+    ///
+    /// # Errors
+    ///
+    /// Any IO Error or Deserialization error
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// extern crate transmission_rpc;
+    ///
+    /// use std::env;
+    /// use dotenv::dotenv;
+    /// use transmission_rpc::TransClient;
+    /// use transmission_rpc::types::{Result, RpcResponse, BasicAuth, PortTest};
+    ///
+    /// #[tokio::main]
+    /// async fn main() -> Result<()> {
+    ///     dotenv().ok();
+    ///     env_logger::init();
+    ///     let url= env::var("TURL")?;
+    ///     let basic_auth = BasicAuth{user: env::var("TUSER")?, password: env::var("TPWD")?};
+    ///     let client = TransClient::with_auth(&url, basic_auth);
+    ///     let response: Result<RpcResponse<PortTest>> = client.port_test().await;
+    ///     match response {
+    ///         Ok(_) => println!("Yay!"),
+    ///         Err(_) => panic!("Oh no!")
+    ///     }
+    ///     println!("Rpc response is ok: {}", response?.is_ok());
+    ///     Ok(())
+    /// }
+    /// ```
+    pub async fn port_test(&self) -> Result<RpcResponse<PortTest>> {
+        self.call(RpcRequest::port_test()).await
+    }
+
     /// Performs a torrent get call
     /// fileds - if None then ALL fields
     /// ids - if None then All items
